package debugutil

import (
	"fmt"
	"os"

	"github.com/davecgh/go-spew/spew"
)

// SaveToFile 将任意数据结构保存到文件中进行调试
// filename: 不需要包含路径和扩展名
// data: 要保存的数据结构
func SaveToFile(filename string, data interface{}) error {
	// 确保输出目录存在
	if err := os.MkdirAll("output", 0755); err != nil {
		return fmt.Errorf("创建输出目录失败: %v", err)
	}

	// 使用自定义的 ConfigState 生成格式化的输出
	cs := spew.ConfigState{
		Indent:                  "  ",
		DisableCapacities:       true,
		DisablePointerAddresses: true,
		SortKeys:                true,
		SpewKeys:                true,
	}

	// 生成输出内容
	output := cs.Sdump(data)

	// 构建完整的文件路径
	fullPath := fmt.Sprintf("output/%s.json", filename)

	fmt.Printf("%s保存在%s\n", filename, fullPath)

	// 写入文件
	if err := os.WriteFile(fullPath, []byte(output), 0644); err != nil {
		return fmt.Errorf("写入文件失败: %v", err)
	}

	return nil
}
